```
Usage: vcd vapp network services firewall [OPTIONS] COMMAND [ARGS]...

  Manages firewall service of vapp network.

      Examples
          vcd vapp network services firewall enable-firewall vapp_name
                  network_name --enable
              Enable firewall service.

Options:
  -h, --help  Show this message and exit.

Commands:
  enable-firewall  Enable firewall service

```
